Class: Google::Iam::V1::Logging::AuditData
- Inherits:
-
Object
- Object
- Google::Iam::V1::Logging::AuditData
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/iam/v1/logging/audit_data.rb
Overview
Audit log information specific to Cloud IAM. This message is serialized
as an Any type in the ServiceData message of an
AuditLog message.
Instance Attribute Summary collapse
-
#policy_delta ⇒ ::Google::Iam::V1::PolicyDelta
Policy delta between the original policy and the newly set policy.
Instance Attribute Details
#policy_delta ⇒ ::Google::Iam::V1::PolicyDelta
Returns Policy delta between the original policy and the newly set policy.
30 31 32 33 |
# File 'proto_docs/google/iam/v1/logging/audit_data.rb', line 30 class AuditData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |